==> pymuxkali-1.3.tar.gz: pymuxkali-1.3/README.md <==
# pymuxkali
This is a python script by which you can install Kali Nethunter (Kali Linux) in your termux application without rooted phone.

## Download Counter
<p align="left">
<a href="https://github.com/rc-chuah/pymuxkali/releases/latest"><img alt="GitHub all releases" src="https://img.shields.io/github/downloads/rc-chuah/pymuxkali/total?label=GITHUB%20DOWNLOADS&style=for-the-badge"></a>
<a href="https://pypi.org/project/pymuxkali"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/pymuxkali?label=PYPI%20DOWNLOADS&style=for-the-badge"></a>
</p>

## Usage
### How To Use pymuxkali
1. Install Dependencies In Termux `pkg update -y && pkg install git python -y`
2. Install pymuxkali `pip install git+https://github.com/rc-chuah/pymuxkali`
3. Run It On Termux Terminal `pymuxkali <options>`
#### Update pymuxkali
- Update To The Latest pymuxkali Run This Command Again `pip install git+https://github.com/rc-chuah/pymuxkali`
### pymuxkali options
```
usage: pymuxkali [-f] [-m] [-u] [-h]

Kali-Nethunter-In-Termux Installer

options:
  -f, --full       Install Kali Nethunter In Termux Full Version.
  -m, --minimal    Install Kali Nethunter In Termux Minimal Version.
  -u, --uninstall  Uninstall Kali Nethunter In Termux.
  -h, --help       Show This Help Message And Exit.
```
## Usage
### How To Use pymuxkali Using PyPI (Python Package Index)
1. Install Dependencies In Termux `pkg update -y && pkg install python -y`
2. Install pymuxkali `pip install pymuxkali`
3. Run It On Termux Terminal `pymuxkali <options>`
#### Update pymuxkali Using PyPI (Python Package Index)
- Update To The Latest pymuxkali Using PyPI (Python Package Index) `pip install --upgrade pymuxkali`
### PyPI pymuxkali options
```
usage: pymuxkali [-f] [-m] [-u] [-h]

Kali-Nethunter-In-Termux Installer

options:
  -f, --full       Install Kali Nethunter In Termux Full Version.
  -m, --minimal    Install Kali Nethunter In Termux Minimal Version.
  -u, --uninstall  Uninstall Kali Nethunter In Termux.
  -h, --help       Show This Help Message And Exit.
```

==> pymuxkali-1.5.tar.gz: pymuxkali-1.5/README.md <==
# pymuxkali
This is a python script by which you can install Kali Nethunter (Kali Linux) in your termux application without rooted phone.

## Download Counter
<p align="left">
<a href="https://github.com/rc-chuah/pymuxkali/releases/latest"><img alt="GitHub all releases" src="https://img.shields.io/github/downloads/rc-chuah/pymuxkali/total?label=GITHUB%20DOWNLOADS&style=for-the-badge&color=brightgreen"></a>
<a href="https://pypi.org/project/pymuxkali"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/pymuxkali?label=PYPI%20DOWNLOADS&style=for-the-badge&color=brightgreen"></a>
</p>

## Usage
### How To Use pymuxkali
1. Install Dependencies In Termux `pkg update -y && pkg install git python -y`
2. Install pymuxkali `pip install git+https://github.com/rc-chuah/pymuxkali`
3. Run It On Termux Terminal `pymuxkali <options>`
#### Update pymuxkali
- Update To The Latest pymuxkali Run This Command Again `pip install git+https://github.com/rc-chuah/pymuxkali`
### pymuxkali options
```
usage: pymuxkali [-f] [-m] [-n] [-u] [-h]

Kali-Nethunter-In-Termux Installer

options:
  -f, --full       Install Kali Nethunter In Termux Full Version.
  -m, --minimal    Install Kali Nethunter In Termux Minimal Version.
  -n, --nano       Install Kali Nethunter In Termux Nano Version.
  -u, --uninstall  Uninstall Kali Nethunter In Termux.
  -h, --help       Show This Help Message And Exit.
```
## Usage
### How To Use pymuxkali Using PyPI (Python Package Index)
1. Install Dependencies In Termux `pkg update -y && pkg install python -y`
2. Install pymuxkali `pip install pymuxkali`
3. Run It On Termux Terminal `pymuxkali <options>`
#### Update pymuxkali Using PyPI (Python Package Index)
- Update To The Latest pymuxkali Using PyPI (Python Package Index) `pip install --upgrade pymuxkali`
### PyPI pymuxkali options
```
usage: pymuxkali [-f] [-m] [-n] [-u] [-h]

Kali-Nethunter-In-Termux Installer

options:
  -f, --full       Install Kali Nethunter In Termux Full Version.
  -m, --minimal    Install Kali Nethunter In Termux Minimal Version.
  -n, --nano       Install Kali Nethunter In Termux Nano Version.
  -u, --uninstall  Uninstall Kali Nethunter In Termux.
  -h, --help       Show This Help Message And Exit.
```
